@@ -1,16 +1,16 @@
 ;(function(){
   var map = {
-  "commitId": "b4e46872e96a11123fb76c1125cd97f1519608d6",
-  "branchName": "release-client-5.15.x",
-  "buildTime": "2023-09-01 03:11:22 GMT",
-  "buildVersion": "5.1.689",
+  "commitId": "23fed4f5b5cf0aaa216c2088261a14501e9c4daa",
+  "branchName": "release-client-5.x",
+  "buildTime": "2023-09-15 10:07:55 GMT",
+  "buildVersion": "5.1.727",
   "css": [
     "@zoom/client-calendar/static/css/chunk-vendors.dc891ce4.css",
-    "@zoom/client-calendar/static/css/app.abf9bb7a.css"
+    "@zoom/client-calendar/static/css/app.c3b5793e.css"
   ],
   "js": [
-    "@zoom/client-calendar/static/js/chunk-vendors.4fbea1be.js",
-    "@zoom/client-calendar/static/js/app.3d9a7ec3.js"
+    "@zoom/client-calendar/static/js/chunk-vendors.14206689.js",
+    "@zoom/client-calendar/static/js/app.aa7bcce3.js"
   ],
   "key": "@zoom/client-calendar"
 };
