@@ -1,16 +1,16 @@
 ;(function(){
   var map = {
-  "commitId": "264b6ea61eb0cc5f148da820e40509cb89aea075",
-  "branchName": "release-client-5.15.x",
-  "buildTime": "Fri, 21 Jul 2023 09:14:22 GMT",
-  "buildVersion": "5.1.333",
+  "commitId": "e9703c4d610ffcbd5eb4a60be830672deec038da",
+  "branchName": "release-client-5.x",
+  "buildTime": "Wed, 13 Sep 2023 08:04:12 GMT",
+  "buildVersion": "5.1.419",
   "css": [
     "@zoom/client-scheduler/static/css/chunk-vendors.af34567c.css",
     "@zoom/client-scheduler/static/css/index.f31cf0bd.css"
   ],
   "js": [
-    "@zoom/client-scheduler/static/js/chunk-vendors.c685a8ed.js",
-    "@zoom/client-scheduler/static/js/index.7adefedc.js"
+    "@zoom/client-scheduler/static/js/chunk-vendors.ca68f063.js",
+    "@zoom/client-scheduler/static/js/index.33235476.js"
   ]
 };
   var prefix = 'https://dev-integration.zoomdev.us/fe-static/';
